@@ -17,6 +17,7 @@ from datetime import datetime
 from typing import IO, Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
+from botocore.response import StreamingBody
 
 from .literals import (
     AggregationPeriodType,
@@ -27,27 +28,27 @@ from .literals import (
 )
 from .paginator import ListProfileTimesPaginator
 from .type_defs import (
-    AddNotificationChannelsResponseTypeDef,
+    AddNotificationChannelsResponseResponseTypeDef,
     AgentOrchestrationConfigTypeDef,
-    BatchGetFrameMetricDataResponseTypeDef,
+    BatchGetFrameMetricDataResponseResponseTypeDef,
     ChannelTypeDef,
-    ConfigureAgentResponseTypeDef,
-    CreateProfilingGroupResponseTypeDef,
-    DescribeProfilingGroupResponseTypeDef,
+    ConfigureAgentResponseResponseTypeDef,
+    CreateProfilingGroupResponseResponseTypeDef,
+    DescribeProfilingGroupResponseResponseTypeDef,
     FrameMetricTypeDef,
-    GetFindingsReportAccountSummaryResponseTypeDef,
-    GetNotificationConfigurationResponseTypeDef,
-    GetPolicyResponseTypeDef,
-    GetProfileResponseTypeDef,
-    GetRecommendationsResponseTypeDef,
-    ListFindingsReportsResponseTypeDef,
-    ListProfileTimesResponseTypeDef,
-    ListProfilingGroupsResponseTypeDef,
-    ListTagsForResourceResponseTypeDef,
-    PutPermissionResponseTypeDef,
-    RemoveNotificationChannelResponseTypeDef,
-    RemovePermissionResponseTypeDef,
-    UpdateProfilingGroupResponseTypeDef,
+    GetFindingsReportAccountSummaryResponseResponseTypeDef,
+    GetNotificationConfigurationResponseResponseTypeDef,
+    GetPolicyResponseResponseTypeDef,
+    GetProfileResponseResponseTypeDef,
+    GetRecommendationsResponseResponseTypeDef,
+    ListFindingsReportsResponseResponseTypeDef,
+    ListProfileTimesResponseResponseTypeDef,
+    ListProfilingGroupsResponseResponseTypeDef,
+    ListTagsForResourceResponseResponseTypeDef,
+    PutPermissionResponseResponseTypeDef,
+    RemoveNotificationChannelResponseResponseTypeDef,
+    RemovePermissionResponseResponseTypeDef,
+    UpdateProfilingGroupResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -79,7 +80,7 @@ class Exceptions:
 
 class CodeGuruProfilerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html)
     """
 
@@ -88,9 +89,11 @@ class CodeGuruProfilerClient:
 
     def add_notification_channels(
         self, *, channels: List["ChannelTypeDef"], profilingGroupName: str
-    ) -> AddNotificationChannelsResponseTypeDef:
+    ) -> AddNotificationChannelsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.add_notification_channels)
+        Add up to 2 anomaly notifications channels for a profiling group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.add_notification_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#add_notification_channels)
         """
 
@@ -98,20 +101,25 @@ class CodeGuruProfilerClient:
         self,
         *,
         profilingGroupName: str,
-        endTime: datetime = None,
+        endTime: Union[datetime, str] = None,
         frameMetrics: List["FrameMetricTypeDef"] = None,
         period: str = None,
-        startTime: datetime = None,
+        startTime: Union[datetime, str] = None,
         targetResolution: AggregationPeriodType = None
-    ) -> BatchGetFrameMetricDataResponseTypeDef:
+    ) -> BatchGetFrameMetricDataResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.batch_get_frame_metric_data)
+        Returns the time series of values for a requested list of frame metrics from a
+        time period.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.batch_get_frame_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#batch_get_frame_metric_data)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#can_paginate)
         """
 
@@ -121,9 +129,11 @@ class CodeGuruProfilerClient:
         profilingGroupName: str,
         fleetInstanceId: str = None,
         metadata: Dict[MetadataFieldType, str] = None
-    ) -> ConfigureAgentResponseTypeDef:
+    ) -> ConfigureAgentResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#configure_agent)
         """
 
@@ -135,23 +145,29 @@ class CodeGuruProfilerClient:
         agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef" = None,
         computePlatform: ComputePlatformType = None,
         tags: Dict[str, str] = None
-    ) -> CreateProfilingGroupResponseTypeDef:
+    ) -> CreateProfilingGroupResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#create_profiling_group)
         """
 
     def delete_profiling_group(self, *, profilingGroupName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
+        Deletes a profiling group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#delete_profiling_group)
         """
 
     def describe_profiling_group(
         self, *, profilingGroupName: str
-    ) -> DescribeProfilingGroupResponseTypeDef:
+    ) -> DescribeProfilingGroupResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#describe_profiling_group)
         """
 
@@ -163,29 +179,37 @@ class CodeGuruProfilerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#generate_presigned_url)
         """
 
     def get_findings_report_account_summary(
         self, *, dailyReportsOnly: bool = None, maxResults: int = None, nextToken: str = None
-    ) -> GetFindingsReportAccountSummaryResponseTypeDef:
+    ) -> GetFindingsReportAccountSummaryResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_findings_report_account_summary)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_findings_report_account_summary)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_findings_report_account_summary)
         """
 
     def get_notification_configuration(
         self, *, profilingGroupName: str
-    ) -> GetNotificationConfigurationResponseTypeDef:
+    ) -> GetNotificationConfigurationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_notification_configuration)
+        Get the current configuration for anomaly notifications for a profiling group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_notification_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_notification_configuration)
         """
 
-    def get_policy(self, *, profilingGroupName: str) -> GetPolicyResponseTypeDef:
+    def get_policy(self, *, profilingGroupName: str) -> GetPolicyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
+        Returns the JSON-formatted resource-based policy on a profiling group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_policy)
         """
 
@@ -194,79 +218,101 @@ class CodeGuruProfilerClient:
         *,
         profilingGroupName: str,
         accept: str = None,
-        endTime: datetime = None,
+        endTime: Union[datetime, str] = None,
         maxDepth: int = None,
         period: str = None,
-        startTime: datetime = None
-    ) -> GetProfileResponseTypeDef:
+        startTime: Union[datetime, str] = None
+    ) -> GetProfileResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
+        Gets the aggregated profile of a profiling group for a specified time range.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_profile)
         """
 
     def get_recommendations(
-        self, *, endTime: datetime, profilingGroupName: str, startTime: datetime, locale: str = None
-    ) -> GetRecommendationsResponseTypeDef:
+        self,
+        *,
+        endTime: Union[datetime, str],
+        profilingGroupName: str,
+        startTime: Union[datetime, str],
+        locale: str = None
+    ) -> GetRecommendationsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_recommendations)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_recommendations)
         """
 
     def list_findings_reports(
         self,
         *,
-        endTime: datetime,
+        endTime: Union[datetime, str],
         profilingGroupName: str,
-        startTime: datetime,
+        startTime: Union[datetime, str],
         dailyReportsOnly: bool = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListFindingsReportsResponseTypeDef:
+    ) -> ListFindingsReportsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_findings_reports)
+        List the available reports for a given profiling group and time range.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_findings_reports)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_findings_reports)
         """
 
     def list_profile_times(
         self,
         *,
-        endTime: datetime,
+        endTime: Union[datetime, str],
         period: AggregationPeriodType,
         profilingGroupName: str,
-        startTime: datetime,
+        startTime: Union[datetime, str],
         maxResults: int = None,
         nextToken: str = None,
         orderBy: OrderByType = None
-    ) -> ListProfileTimesResponseTypeDef:
+    ) -> ListProfileTimesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
+        Lists the start times of the available aggregated profiles of a profiling group
+        for an aggregation period within the specified time range.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_profile_times)
         """
 
     def list_profiling_groups(
         self, *, includeDescription: bool = None, maxResults: int = None, nextToken: str = None
-    ) -> ListProfilingGroupsResponseTypeDef:
+    ) -> ListProfilingGroupsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_profiling_groups)
         """
 
-    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
+    def list_tags_for_resource(
+        self, *, resourceArn: str
+    ) -> ListTagsForResourceResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_tags_for_resource)
+        Returns a list of the tags that are assigned to a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_tags_for_resource)
         """
 
     def post_agent_profile(
         self,
         *,
-        agentProfile: Union[bytes, IO[bytes]],
+        agentProfile: Union[bytes, IO[bytes], StreamingBody],
         contentType: str,
         profilingGroupName: str,
         profileToken: str = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#post_agent_profile)
         """
 
@@ -277,25 +323,32 @@ class CodeGuruProfilerClient:
         principals: List[str],
         profilingGroupName: str,
         revisionId: str = None
-    ) -> PutPermissionResponseTypeDef:
+    ) -> PutPermissionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
+        Adds permissions to a profiling group's resource-based policy that are provided
+        using an action group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#put_permission)
         """
 
     def remove_notification_channel(
         self, *, channelId: str, profilingGroupName: str
-    ) -> RemoveNotificationChannelResponseTypeDef:
+    ) -> RemoveNotificationChannelResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_notification_channel)
+        Remove one anomaly notifications channel for a profiling group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_notification_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#remove_notification_channel)
         """
 
     def remove_permission(
         self, *, actionGroup: Literal["agentPermissions"], profilingGroupName: str, revisionId: str
-    ) -> RemovePermissionResponseTypeDef:
+    ) -> RemovePermissionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#remove_permission)
         """
 
@@ -308,19 +361,25 @@ class CodeGuruProfilerClient:
         comment: str = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.submit_feedback)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.submit_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#submit_feedback)
         """
 
     def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.tag_resource)
+        Use to assign one or more tags to a resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#tag_resource)
         """
 
     def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.untag_resource)
+        Use to remove one or more tags from a resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#untag_resource)
         """
 
@@ -329,9 +388,11 @@ class CodeGuruProfilerClient:
         *,
         agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef",
         profilingGroupName: str
-    ) -> UpdateProfilingGroupResponseTypeDef:
+    ) -> UpdateProfilingGroupResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#update_profiling_group)
         """
 
@@ -339,5 +400,6 @@ class CodeGuruProfilerClient:
         self, operation_name: Literal["list_profile_times"]
     ) -> ListProfileTimesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
         """
