@@ -19,32 +19,33 @@ Usage::
     ```
 """
 from datetime import datetime
-from typing import Iterator
+from typing import Iterator, Union
 
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import AggregationPeriodType, OrderByType
-from .type_defs import ListProfileTimesResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import ListProfileTimesResponseResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListProfileTimesPaginator",)
 
 
 class ListProfileTimesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
     """
 
     def paginate(
         self,
         *,
-        endTime: datetime,
+        endTime: Union[datetime, str],
         period: AggregationPeriodType,
         profilingGroupName: str,
-        startTime: datetime,
+        startTime: Union[datetime, str],
         orderBy: OrderByType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListProfileTimesResponseTypeDef]:
+    ) -> Iterator[ListProfileTimesResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.96/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
         """
